import Chart from 'chart.js';
import interpolate from 'color-interpolate';
import 'mdn-polyfills/Node.prototype.before';
import 'mdn-polyfills/Array.prototype.includes';

(({ behaviors }, $$, $) => {
  behaviors.dashboardsChartTable = {
    attach(context) {
      const charts = $$(context, '[data-app=chart]:not(.processed)');
      charts.forEach((c) => {
        c.classList.add('processed');
        this.init(c, c.getAttribute('data-chart-type'));
      })
    },
    getLabels(t) {
      const labels = [];
      $$(t, 'thead th').forEach((v) => {
        labels.push(v.textContent)
      })
      return labels;
    },
    getDataSingle(e) {
      const t = $(e, 'table');
      const dataset = {
        labels: [],
        datasets: []
      };
      let data = [];
      let colormap = interpolate(['yellow', 'green']);
      $$(t, 'tbody tr td:first-child').forEach((v) => {
        dataset.labels.push(v.textContent);
      })
      $$(t, 'tbody tr').forEach(v => {
        $$(v, 'td:last-child').forEach(td => {
          data.push(td.textContent);
        })
      })

      let max =  Math.max.apply(Math, data);

      dataset.datasets.push({data: data, backgroundColor: []});
      dataset.datasets.forEach(d => {
        d.data.forEach(v => {
          if (max == 0) {
            d.backgroundColor.push(0);
            return;
          }
          const p = ((100/max)*v)/100;
          d.backgroundColor.push(colormap(p));
        })
      })

      return dataset;
    },
    getData(e) {
      const t = $(e, 'table');
      if ($$(t,'th').length == 2) {
        return this.getDataSingle(e);
      }
      const dataset = {
        labels: [],
        datasets: []
      };
      let max = 0;

      let colormap = interpolate(['red', 'green']);

      $$(t, 'tbody tr').forEach((v) => {
        let data = {
          label: '',
          data: [],
          backgroundColor: []
        }
        dataset.labels.push($(v, 'td').textContent);
        $$(v, 'td').slice(1).forEach((d) => {
          if (parseInt(d.textContent)) {
            data.data.push(parseInt(d.textContent))
            return;
          }
          data.data.push(d.textContent)
        })
        let maxData =  Math.max.apply(Math, data.data);
        if (maxData > max) {
          max = maxData;
        }
        dataset.datasets.push(data);
      })
      dataset.datasets.forEach(d => {
        d.data.forEach(v => {
          const p = ((100/max)*v)/100;
          d.backgroundColor.push(colormap(p));
        })
      })
      return dataset;
    },
    init(e, type) {
      const allowedBars = [
        'bar',
        'pie',
        'line',
        'radar',
        'doughnut',
        'polarArea',
        'bubble',
        'scatter',
      ];
      if (!type || !allowedBars.includes(type)) {
        type = 'bar';
      }
      $(e, 'div').before(document.createElement('canvas'))
      const canvas = $(e, 'canvas');
      const data = this.getData(e);
      e.chart = new Chart(canvas, {
        type: type,
        data: data,
        options: {
          legend: {
            display: false,
          }
        }
      });
    }
  }
})(Drupal, function(e,s) {
  return Array.prototype.slice.call(e.querySelectorAll(s));
}, function(e,s) {
  return e.querySelector(s);
})
